package cmdUser

import (
    "errors"
    u "nexus-client/utils"
    g "nexus-client/globals"
)

type Unlock struct {
    Name string
}

func (cmd *Unlock)GetName() string {
    return cmd.Name
}

func (cmd *Unlock)GetDesc() []string {
    return []string{
        "Unlocks one or more users.",
        "Requires USER_UNLOCK user capability."}
}

func (cmd *Unlock)PrintUsage() {
    for _, desc := range cmd.GetDesc() {
        u.PrintlnErr(desc)
    }
    u.PrintlnErr("―――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――")
    u.PrintlnErr("USAGE: "+cmd.GetName()+" email [email ...]")
    u.PrintlnErr("―――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――")
}

func (cmd *Unlock)Run(args []string) int {
    argc := len(args)
    if argc < 1 {
        cmd.PrintUsage()
        return 1
    }

    statusCode := 0

    // Iterates through each user (email) and unlock them
    for i:= range(args) {
        email := args[i]
        if err := cmd.runRequest(email); err != nil {
            u.PrintlnErr(err.Error())
            statusCode = 1
        } else {
            u.Println("Successfully unlocked user "+email)
        }
    }

    return statusCode
}

func (cmd *Unlock)runRequest(email string) error {
    client := g.GetInstance().Client
    host := g.GetInstance().Host

    resp, err := client.R().Put(host+"/users/"+email+"/unlock")
    if err != nil {
        return errors.New("Error: "+err.Error())
    }

    if resp.IsSuccess() {
        return nil
    } else {
        return errors.New("Error: "+resp.Status()+": "+resp.String())
    }
}
